==> tiledb-cf-0.2.0.tar.gz: tiledb-cf-0.2.0/README.md <==
<a href="https://tiledb.com"><img src="https://github.com/TileDB-Inc/TileDB/raw/dev/doc/source/_static/tiledb-logo_color_no_margin_@4x.png" alt="TileDB logo" width="400"></a>

# TileDB-CF-Py

The TileDB-CF-Py library is a Python library for supporting the NetCDF data model in the [TileDB storage engine](https://github.com/TileDB-Inc/TileDB). TileDB-CF-Py provides readers and writers for viewing and manipulating TileDB arrays and groups using TileDB CF Dataspaces - a special TileDB group that follows the requirements in [tiledb-cf-spec.md](tiledb-cf-spec.md).

## Documentation

  * Documentation (TBD)
  * API Documentation (TBD)
  * [TileDB CF Dataspace Specification](tiledb-cf-spec.md)

## TileDB Quick Links

  * [Homepage](https://tiledb.com)
  * [Documentation](https://docs.tiledb.com/main/)
  * [Forum](https://forum.tiledb.io/)
  * [Organization](https://github.com/TileDB-Inc/)

## Quick Installation

This project is currently in early development, and is only available on [GitHub](https://github.com/).

Upon release it will be available from either [conda-forge](https://anaconda.org/conda-forge/tiledb-py) with
[conda](https://conda.io/docs/):

```bash
conda install -c conda-forge tiledb-cf
```

or from [PyPI](https://pypi.org/project/tiledb/) with ``pip``:

```bash
pip install tiledb-cf

```

## Command Line Interface

TileDB-CF provides a command line interface. Currently, it has the following commands:

```bash
Usage: tiledb-cf netcdf-convert [OPTIONS]

  Converts a NetCDF input file to nested TileDB groups.

Options:
  -i, --input-file TEXT           The path or URI to the NetCDF file that will be converted.  [required]

  -o, --output-uri TEXT           The URI for the output TileDB group. [required]

  --input-group-path TEXT         The path in the input NetCDF for the root group that will be converted.  [default: /]

  --recursive / --no-recursive    Recursively convert all groups contained in the input group path.  [default: True]

  -k, --output-key TEXT           Key for the generated TileDB arrays.

  --unlimited-dim-size INTEGER    Size to convert unlimited dimensions to. [default: 10000]

  --dim-dtype [int8|int16|int32|int64|uint8|uint16|uint32|uint64]
                                  The data type for TileDB dimensions created from converted NetCDF.  [default: uint64]

  --help                          Show this message and exit.
```

## Development

For information on contributing to this project see the [CONTRIBUTING](CONTRIBUTING.md) document.

==> tiledb-cf-0.4.1.tar.gz: tiledb-cf-0.4.1/README.md <==
<a href="https://tiledb.com"><img src="https://github.com/TileDB-Inc/TileDB/raw/dev/doc/source/_static/tiledb-logo_color_no_margin_@4x.png" alt="TileDB logo" width="400"></a>

# TileDB-CF-Py

The TileDB-CF-Py library is a Python library for supporting the NetCDF data model in the [TileDB storage engine](https://github.com/TileDB-Inc/TileDB). TileDB-CF-Py provides readers and writers for viewing and manipulating TileDB arrays and groups using TileDB CF Dataspaces - a special TileDB group that follows the requirements in [tiledb-cf-spec.md](tiledb-cf-spec.md).

## Documentation

  * Documentation (TBD)
  * API Documentation (TBD)
  * [TileDB CF Dataspace Specification](tiledb-cf-spec.md)

## TileDB Quick Links

  * [Homepage](https://tiledb.com)
  * [Documentation](https://docs.tiledb.com/main/)
  * [Forum](https://forum.tiledb.io/)
  * [Organization](https://github.com/TileDB-Inc/)

## Quick Installation

This project is available from [PyPI](https://pypi.org/project/tiledb/) and may be installed with ``pip``:

```bash
pip install tiledb-cf

```

## Command Line Interface

TileDB-CF provides a command line interface. Currently, it has the following commands:

```bash
Usage: tiledb-cf netcdf-convert [OPTIONS]

  Converts a NetCDF input file to nested TileDB groups.

Options:
  -i, --input-file TEXT           The path or URI to the NetCDF file that will be converted.  [required]

  -o, --output-uri TEXT           The URI for the output TileDB group. [required]

  --input-group-path TEXT         The path in the input NetCDF for the root group that will be converted.  [default: /]

  --recursive / --no-recursive    Recursively convert all groups contained in the input group path.  [default: True]

  -k, --output-key TEXT           Key for the generated TileDB arrays.

  --unlimited-dim-size INTEGER    Size to convert unlimited dimensions to. [default: 10000]

  --dim-dtype [int8|int16|int32|int64|uint8|uint16|uint32|uint64]
                                  The data type for TileDB dimensions created from converted NetCDF.  [default: uint64]

  --help                          Show this message and exit.
```

## Development

For information on contributing to this project see the [CONTRIBUTING](CONTRIBUTING.md) document.
